@@ -15,9 +15,9 @@
 import datetime
 import uuid
 
+import http.client
 import oslo_context.context
 from oslo_serialization import jsonutils
-from six.moves import http_client
 from testtools import matchers
 import webtest
 
@@ -247,7 +247,7 @@ class RestfulTestCase(unit.SQLDriverOverrides, rest.RestfulTestCase,
             domain_id=DEFAULT_DOMAIN_ID)
         self.default_domain_user_id = self.default_domain_user['id']
 
-        # create & grant policy.json's default role for admin_required
+        # create & grant policy.yaml's default role for admin_required
         self.role = unit.new_role_ref(name='admin')
         self.role_id = self.role['id']
         PROVIDERS.role_api.create_role(self.role_id, self.role)
@@ -442,7 +442,7 @@ class RestfulTestCase(unit.SQLDriverOverrides, rest.RestfulTestCase,
         r = self.v3_create_token(auth)
         return r.headers.get('X-Subject-Token')
 
-    def v3_create_token(self, auth, expected_status=http_client.CREATED):
+    def v3_create_token(self, auth, expected_status=http.client.CREATED):
         return self.admin_request(method='POST',
                                   path='/v3/auth/tokens',
                                   body=auth,
@@ -471,29 +471,29 @@ class RestfulTestCase(unit.SQLDriverOverrides, rest.RestfulTestCase,
 
         return self.admin_request(path=path, token=token, **kwargs)
 
-    def get(self, path, expected_status=http_client.OK, **kwargs):
+    def get(self, path, expected_status=http.client.OK, **kwargs):
         return self.v3_request(path, method='GET',
                                expected_status=expected_status, **kwargs)
 
-    def head(self, path, expected_status=http_client.NO_CONTENT, **kwargs):
+    def head(self, path, expected_status=http.client.NO_CONTENT, **kwargs):
         r = self.v3_request(path, method='HEAD',
                             expected_status=expected_status, **kwargs)
         self.assertEqual(b'', r.body)
         return r
 
-    def post(self, path, expected_status=http_client.CREATED, **kwargs):
+    def post(self, path, expected_status=http.client.CREATED, **kwargs):
         return self.v3_request(path, method='POST',
                                expected_status=expected_status, **kwargs)
 
-    def put(self, path, expected_status=http_client.NO_CONTENT, **kwargs):
+    def put(self, path, expected_status=http.client.NO_CONTENT, **kwargs):
         return self.v3_request(path, method='PUT',
                                expected_status=expected_status, **kwargs)
 
-    def patch(self, path, expected_status=http_client.OK, **kwargs):
+    def patch(self, path, expected_status=http.client.OK, **kwargs):
         return self.v3_request(path, method='PATCH',
                                expected_status=expected_status, **kwargs)
 
-    def delete(self, path, expected_status=http_client.NO_CONTENT, **kwargs):
+    def delete(self, path, expected_status=http.client.NO_CONTENT, **kwargs):
         return self.v3_request(path, method='DELETE',
                                expected_status=expected_status, **kwargs)
 
